#ifndef AVOID_PRECOMPILED
/* C file produced by GAC */
#include "compiled.h"

/* global variables used in handlers */
static libGAP_GVar libGAP_G_IS__FUNCTION;
static libGAP_Obj  libGAP_GF_IS__FUNCTION;
static libGAP_GVar libGAP_G_ADD__LIST;
static libGAP_Obj  libGAP_GF_ADD__LIST;
static libGAP_GVar libGAP_G_Error;
static libGAP_Obj  libGAP_GF_Error;
static libGAP_GVar libGAP_G_IS__IDENTICAL__OBJ;
static libGAP_Obj  libGAP_GF_IS__IDENTICAL__OBJ;
static libGAP_GVar libGAP_G_AND__FLAGS;
static libGAP_Obj  libGAP_GF_AND__FLAGS;
static libGAP_GVar libGAP_G_HASH__FLAGS;
static libGAP_Obj  libGAP_GF_HASH__FLAGS;
static libGAP_GVar libGAP_G_IS__SUBSET__FLAGS;
static libGAP_Obj  libGAP_GF_IS__SUBSET__FLAGS;
static libGAP_GVar libGAP_G_TRUES__FLAGS;
static libGAP_Obj  libGAP_GF_TRUES__FLAGS;
static libGAP_GVar libGAP_G_FLAGS__FILTER;
static libGAP_Obj  libGAP_GF_FLAGS__FILTER;
static libGAP_GVar libGAP_G_LEN__LIST;
static libGAP_Obj  libGAP_GF_LEN__LIST;
static libGAP_GVar libGAP_G_HIDDEN__IMPS;
static libGAP_Obj  libGAP_GC_HIDDEN__IMPS;
static libGAP_GVar libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE;
static libGAP_Obj  libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
static libGAP_GVar libGAP_G_WITH__HIDDEN__IMPS__FLAGS__COUNT;
static libGAP_GVar libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS;
static libGAP_Obj  libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS;
static libGAP_GVar libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT;
static libGAP_Obj  libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT;
static libGAP_GVar libGAP_G_CLEAR__HIDDEN__IMP__CACHE;
static libGAP_GVar libGAP_G_BIND__GLOBAL;
static libGAP_Obj  libGAP_GF_BIND__GLOBAL;
static libGAP_GVar libGAP_G_IMPLICATIONS;
static libGAP_Obj  libGAP_GC_IMPLICATIONS;
static libGAP_GVar libGAP_G_WITH__IMPS__FLAGS__CACHE;
static libGAP_Obj  libGAP_GC_WITH__IMPS__FLAGS__CACHE;
static libGAP_GVar libGAP_G_WITH__IMPS__FLAGS__COUNT;
static libGAP_Obj  libGAP_GC_WITH__IMPS__FLAGS__COUNT;
static libGAP_GVar libGAP_G_WITH__IMPS__FLAGS__CACHE__HIT;
static libGAP_Obj  libGAP_GC_WITH__IMPS__FLAGS__CACHE__HIT;
static libGAP_GVar libGAP_G_WITH__IMPS__FLAGS__CACHE__MISS;
static libGAP_Obj  libGAP_GC_WITH__IMPS__FLAGS__CACHE__MISS;
static libGAP_GVar libGAP_G_CLEAR__IMP__CACHE;
static libGAP_GVar libGAP_G_UNBIND__GLOBAL;
static libGAP_Obj  libGAP_GF_UNBIND__GLOBAL;
static libGAP_GVar libGAP_G_WITH__HIDDEN__IMPS__FLAGS;
static libGAP_Obj  libGAP_GF_WITH__HIDDEN__IMPS__FLAGS;
static libGAP_GVar libGAP_G_RANK__FILTERS;
static libGAP_Obj  libGAP_GC_RANK__FILTERS;
static libGAP_GVar libGAP_G_RankFilter;
static libGAP_GVar libGAP_G_RANK__FILTER;
static libGAP_Obj  libGAP_GC_RANK__FILTER;
static libGAP_Obj  libGAP_GF_RANK__FILTER;
static libGAP_GVar libGAP_G_RANK__FILTER__LIST__CURRENT;
static libGAP_Obj  libGAP_GC_RANK__FILTER__LIST__CURRENT;
static libGAP_GVar libGAP_G_RANK__FILTER__LIST;
static libGAP_Obj  libGAP_GC_RANK__FILTER__LIST;
static libGAP_GVar libGAP_G_RANK__FILTER__COUNT;
static libGAP_Obj  libGAP_GC_RANK__FILTER__COUNT;

/* record names used in handlers */

/* information for the functions */
static libGAP_Obj  libGAP_NameFunc[9];
static libGAP_Obj  libGAP_NamsFunc[9];
static libGAP_Int  libGAP_NargFunc[9];
static libGAP_Obj  libGAP_DefaultName;
static libGAP_Obj libGAP_FileName;

/* handler for function 2 */
static libGAP_Obj  libGAP_HdlrFunc2 (
 libGAP_Obj  self,
 libGAP_Obj  a_filter )
{
 libGAP_Obj l_i = 0;
 libGAP_Obj l_flags = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Obj t_5 = 0;
 libGAP_Obj t_6 = 0;
 libGAP_Obj t_7 = 0;
 libGAP_Obj t_8 = 0;
 libGAP_Obj t_9 = 0;
 libGAP_Obj t_10 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* flags := FLAGS_FILTER( filter ); */
 t_2 = libGAP_GF_FLAGS__FILTER;
 t_1 = libGAP_CALL_1ARGS( t_2, a_filter );
 libGAP_CHECK_FUNC_RESULT( t_1 )
 l_flags = t_1;
 
 /* for i in [ 1, 3 .. LEN_LIST( WITH_HIDDEN_IMPS_FLAGS_CACHE ) - 1 ] do */
 t_7 = libGAP_GF_LEN__LIST;
 t_8 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_8, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
 t_6 = libGAP_CALL_1ARGS( t_7, t_8 );
 libGAP_CHECK_FUNC_RESULT( t_6 )
 libGAP_C_DIFF_FIA( t_5, t_6, libGAP_INTOBJ_INT(1) )
 t_4 = libGAP_Range3Check( libGAP_INTOBJ_INT(1), libGAP_INTOBJ_INT(3), t_5 );
 if ( libGAP_IS_SMALL_LIST(t_4) ) {
  t_3 = (libGAP_Obj)(libGAP_UInt)1;
  t_1 = libGAP_INTOBJ_INT(1);
 }
 else {
  t_3 = (libGAP_Obj)(libGAP_UInt)0;
  t_1 = libGAP_CALL_1ARGS( libGAP_GF_ITERATOR, t_4 );
 }
 while ( 1 ) {
  if ( t_3 ) {
   if ( libGAP_LEN_LIST(t_4) < libGAP_INT_INTOBJ(t_1) )  break;
   t_2 = libGAP_ELMV0_LIST( t_4, libGAP_INT_INTOBJ(t_1) );
   t_1 = (libGAP_Obj)(((libGAP_UInt)t_1)+4);
   if ( t_2 == 0 )  continue;
  }
  else {
   if ( libGAP_CALL_1ARGS( libGAP_GF_IS_DONE_ITER, t_1 ) != libGAP_False )  break;
   t_2 = libGAP_CALL_1ARGS( libGAP_GF_NEXT_ITER, t_1 );
  }
  l_i = t_2;
  
  /* if IsBound( WITH_HIDDEN_IMPS_FLAGS_CACHE[i] ) then */
  t_7 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
  libGAP_CHECK_BOUND( t_7, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
  libGAP_CHECK_INT_POS( l_i )
  t_6 = libGAP_C_ISB_LIST( t_7, l_i );
  t_5 = (libGAP_Obj)(libGAP_UInt)(t_6 != libGAP_False);
  if ( t_5 ) {
   
   /* if IS_SUBSET_FLAGS( WITH_HIDDEN_IMPS_FLAGS_CACHE[i + 1], flags ) then */
   t_7 = libGAP_GF_IS__SUBSET__FLAGS;
   t_9 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
   libGAP_CHECK_BOUND( t_9, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
   libGAP_C_SUM_FIA( t_10, l_i, libGAP_INTOBJ_INT(1) )
   libGAP_CHECK_INT_POS( t_10 )
   libGAP_C_ELM_LIST_FPL( t_8, t_9, t_10 )
   t_6 = libGAP_CALL_2ARGS( t_7, t_8, l_flags );
   libGAP_CHECK_FUNC_RESULT( t_6 )
   libGAP_CHECK_BOOL( t_6 )
   t_5 = (libGAP_Obj)(libGAP_UInt)(t_6 != libGAP_False);
   if ( t_5 ) {
    
    /* Unbind( WITH_HIDDEN_IMPS_FLAGS_CACHE[i] ); */
    t_5 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
    libGAP_CHECK_BOUND( t_5, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
    libGAP_C_UNB_LIST( t_5, l_i );
    
    /* Unbind( WITH_HIDDEN_IMPS_FLAGS_CACHE[i + 1] ); */
    t_5 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
    libGAP_CHECK_BOUND( t_5, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
    libGAP_C_SUM_FIA( t_6, l_i, libGAP_INTOBJ_INT(1) )
    libGAP_CHECK_INT_POS( t_6 )
    libGAP_C_UNB_LIST( t_5, t_6 );
    
   }
   /* fi */
   
  }
  /* fi */
  
 }
 /* od */
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 3 */
static libGAP_Obj  libGAP_HdlrFunc3 (
 libGAP_Obj  self,
 libGAP_Obj  a_flags )
{
 libGAP_Obj l_with = 0;
 libGAP_Obj l_changed = 0;
 libGAP_Obj l_imp = 0;
 libGAP_Obj l_hash = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Obj t_5 = 0;
 libGAP_Obj t_6 = 0;
 libGAP_Obj t_7 = 0;
 libGAP_Obj t_8 = 0;
 libGAP_Obj t_9 = 0;
 libGAP_Obj t_10 = 0;
 libGAP_Obj t_11 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* hash := 2 * (HASH_FLAGS( flags ) mod 1009) + 1; */
 t_5 = libGAP_GF_HASH__FLAGS;
 t_4 = libGAP_CALL_1ARGS( t_5, a_flags );
 libGAP_CHECK_FUNC_RESULT( t_4 )
 t_3 = libGAP_MOD( t_4, libGAP_INTOBJ_INT(1009) );
 libGAP_C_PROD_FIA( t_2, libGAP_INTOBJ_INT(2), t_3 )
 libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(1) )
 l_hash = t_1;
 
 /* if IsBound( WITH_HIDDEN_IMPS_FLAGS_CACHE[hash] ) then */
 t_3 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_3, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
 libGAP_CHECK_INT_POS( l_hash )
 t_2 = libGAP_C_ISB_LIST( t_3, l_hash );
 t_1 = (libGAP_Obj)(libGAP_UInt)(t_2 != libGAP_False);
 if ( t_1 ) {
  
  /* if IS_IDENTICAL_OBJ( WITH_HIDDEN_IMPS_FLAGS_CACHE[hash], flags ) then */
  t_3 = libGAP_GF_IS__IDENTICAL__OBJ;
  t_5 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
  libGAP_CHECK_BOUND( t_5, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
  libGAP_C_ELM_LIST_FPL( t_4, t_5, l_hash )
  t_2 = libGAP_CALL_2ARGS( t_3, t_4, a_flags );
  libGAP_CHECK_FUNC_RESULT( t_2 )
  libGAP_CHECK_BOOL( t_2 )
  t_1 = (libGAP_Obj)(libGAP_UInt)(t_2 != libGAP_False);
  if ( t_1 ) {
   
   /* WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT := WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT + 1; */
   t_2 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT;
   libGAP_CHECK_BOUND( t_2, "WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT" )
   libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(1) )
   libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT, t_1 );
   
   /* return WITH_HIDDEN_IMPS_FLAGS_CACHE[hash + 1]; */
   t_2 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
   libGAP_CHECK_BOUND( t_2, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
   libGAP_C_SUM_FIA( t_3, l_hash, libGAP_INTOBJ_INT(1) )
   libGAP_CHECK_INT_POS( t_3 )
   libGAP_C_ELM_LIST_FPL( t_1, t_2, t_3 )
   libGAP_RES_BRK_CURR_STAT();
   libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
   return t_1;
   
  }
  /* fi */
  
 }
 /* fi */
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS := WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS + 1; */
 t_2 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS;
 libGAP_CHECK_BOUND( t_2, "WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS" )
 libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(1) )
 libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS, t_1 );
 
 /* with := flags; */
 l_with = a_flags;
 
 /* changed := true; */
 t_1 = libGAP_True;
 l_changed = t_1;
 
 /* while changed od */
 while ( 1 ) {
  t_1 = (libGAP_Obj)(libGAP_UInt)(l_changed != libGAP_False);
  if ( ! t_1 ) break;
  
  /* changed := false; */
  t_1 = libGAP_False;
  l_changed = t_1;
  
  /* for imp in HIDDEN_IMPS do */
  t_4 = libGAP_GC_HIDDEN__IMPS;
  libGAP_CHECK_BOUND( t_4, "HIDDEN_IMPS" )
  if ( libGAP_IS_SMALL_LIST(t_4) ) {
   t_3 = (libGAP_Obj)(libGAP_UInt)1;
   t_1 = libGAP_INTOBJ_INT(1);
  }
  else {
   t_3 = (libGAP_Obj)(libGAP_UInt)0;
   t_1 = libGAP_CALL_1ARGS( libGAP_GF_ITERATOR, t_4 );
  }
  while ( 1 ) {
   if ( t_3 ) {
    if ( libGAP_LEN_LIST(t_4) < libGAP_INT_INTOBJ(t_1) )  break;
    t_2 = libGAP_ELMV0_LIST( t_4, libGAP_INT_INTOBJ(t_1) );
    t_1 = (libGAP_Obj)(((libGAP_UInt)t_1)+4);
    if ( t_2 == 0 )  continue;
   }
   else {
    if ( libGAP_CALL_1ARGS( libGAP_GF_IS_DONE_ITER, t_1 ) != libGAP_False )  break;
    t_2 = libGAP_CALL_1ARGS( libGAP_GF_NEXT_ITER, t_1 );
   }
   l_imp = t_2;
   
   /* if IS_SUBSET_FLAGS( with, imp[2] ) and not IS_SUBSET_FLAGS( with, imp[1] ) then */
   t_8 = libGAP_GF_IS__SUBSET__FLAGS;
   libGAP_C_ELM_LIST_FPL( t_9, l_imp, libGAP_INTOBJ_INT(2) )
   t_7 = libGAP_CALL_2ARGS( t_8, l_with, t_9 );
   libGAP_CHECK_FUNC_RESULT( t_7 )
   libGAP_CHECK_BOOL( t_7 )
   t_6 = (libGAP_Obj)(libGAP_UInt)(t_7 != libGAP_False);
   t_5 = t_6;
   if ( t_5 ) {
    t_10 = libGAP_GF_IS__SUBSET__FLAGS;
    libGAP_C_ELM_LIST_FPL( t_11, l_imp, libGAP_INTOBJ_INT(1) )
    t_9 = libGAP_CALL_2ARGS( t_10, l_with, t_11 );
    libGAP_CHECK_FUNC_RESULT( t_9 )
    libGAP_CHECK_BOOL( t_9 )
    t_8 = (libGAP_Obj)(libGAP_UInt)(t_9 != libGAP_False);
    t_7 = (libGAP_Obj)(libGAP_UInt)( ! ((libGAP_Int)t_8) );
    t_5 = t_7;
   }
   if ( t_5 ) {
    
    /* with := AND_FLAGS( with, imp[1] ); */
    t_6 = libGAP_GF_AND__FLAGS;
    libGAP_C_ELM_LIST_FPL( t_7, l_imp, libGAP_INTOBJ_INT(1) )
    t_5 = libGAP_CALL_2ARGS( t_6, l_with, t_7 );
    libGAP_CHECK_FUNC_RESULT( t_5 )
    l_with = t_5;
    
    /* changed := true; */
    t_5 = libGAP_True;
    l_changed = t_5;
    
   }
   /* fi */
   
  }
  /* od */
  
 }
 /* od */
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE[hash] := flags; */
 t_1 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_1, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
 libGAP_C_ASS_LIST_FPL( t_1, l_hash, a_flags )
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE[hash + 1] := with; */
 t_1 = libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_1, "WITH_HIDDEN_IMPS_FLAGS_CACHE" )
 libGAP_C_SUM_FIA( t_2, l_hash, libGAP_INTOBJ_INT(1) )
 libGAP_CHECK_INT_POS( t_2 )
 libGAP_C_ASS_LIST_FPL( t_1, t_2, l_with )
 
 /* return with; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return l_with;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 4 */
static libGAP_Obj  libGAP_HdlrFunc4 (
 libGAP_Obj  self )
{
 libGAP_Obj t_1 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* WITH_IMPS_FLAGS_CACHE := [  ]; */
 t_1 = libGAP_NEW_PLIST( libGAP_T_PLIST, 0 );
 libGAP_SET_LEN_PLIST( t_1, 0 );
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE, t_1 );
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 5 */
static libGAP_Obj  libGAP_HdlrFunc5 (
 libGAP_Obj  self,
 libGAP_Obj  a_flags )
{
 libGAP_Obj l_with = 0;
 libGAP_Obj l_changed = 0;
 libGAP_Obj l_imp = 0;
 libGAP_Obj l_hash = 0;
 libGAP_Obj l_hash2 = 0;
 libGAP_Obj l_i = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Obj t_5 = 0;
 libGAP_Obj t_6 = 0;
 libGAP_Obj t_7 = 0;
 libGAP_Obj t_8 = 0;
 libGAP_Obj t_9 = 0;
 libGAP_Obj t_10 = 0;
 libGAP_Obj t_11 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* hash := HASH_FLAGS( flags ) mod 11001; */
 t_3 = libGAP_GF_HASH__FLAGS;
 t_2 = libGAP_CALL_1ARGS( t_3, a_flags );
 libGAP_CHECK_FUNC_RESULT( t_2 )
 t_1 = libGAP_MOD( t_2, libGAP_INTOBJ_INT(11001) );
 l_hash = t_1;
 
 /* for i in [ 0 .. 3 ] do */
 for ( t_1 = libGAP_INTOBJ_INT(0);
       ((libGAP_Int)t_1) <= ((libGAP_Int)libGAP_INTOBJ_INT(3));
       t_1 = (libGAP_Obj)(((libGAP_UInt)t_1)+4) ) {
  l_i = t_1;
  
  /* hash2 := 2 * ((hash + 31 * i) mod 11001) + 1; */
  libGAP_C_PROD_INTOBJS( t_6, libGAP_INTOBJ_INT(31), l_i )
  libGAP_C_SUM_FIA( t_5, l_hash, t_6 )
  t_4 = libGAP_MOD( t_5, libGAP_INTOBJ_INT(11001) );
  libGAP_C_PROD_FIA( t_3, libGAP_INTOBJ_INT(2), t_4 )
  libGAP_C_SUM_FIA( t_2, t_3, libGAP_INTOBJ_INT(1) )
  l_hash2 = t_2;
  
  /* if IsBound( WITH_IMPS_FLAGS_CACHE[hash2] ) then */
  t_4 = libGAP_GC_WITH__IMPS__FLAGS__CACHE;
  libGAP_CHECK_BOUND( t_4, "WITH_IMPS_FLAGS_CACHE" )
  libGAP_CHECK_INT_POS( l_hash2 )
  t_3 = libGAP_C_ISB_LIST( t_4, l_hash2 );
  t_2 = (libGAP_Obj)(libGAP_UInt)(t_3 != libGAP_False);
  if ( t_2 ) {
   
   /* if IS_IDENTICAL_OBJ( WITH_IMPS_FLAGS_CACHE[hash2], flags ) then */
   t_4 = libGAP_GF_IS__IDENTICAL__OBJ;
   t_6 = libGAP_GC_WITH__IMPS__FLAGS__CACHE;
   libGAP_CHECK_BOUND( t_6, "WITH_IMPS_FLAGS_CACHE" )
   libGAP_C_ELM_LIST_FPL( t_5, t_6, l_hash2 )
   t_3 = libGAP_CALL_2ARGS( t_4, t_5, a_flags );
   libGAP_CHECK_FUNC_RESULT( t_3 )
   libGAP_CHECK_BOOL( t_3 )
   t_2 = (libGAP_Obj)(libGAP_UInt)(t_3 != libGAP_False);
   if ( t_2 ) {
    
    /* WITH_IMPS_FLAGS_CACHE_HIT := WITH_IMPS_FLAGS_CACHE_HIT + 1; */
    t_3 = libGAP_GC_WITH__IMPS__FLAGS__CACHE__HIT;
    libGAP_CHECK_BOUND( t_3, "WITH_IMPS_FLAGS_CACHE_HIT" )
    libGAP_C_SUM_FIA( t_2, t_3, libGAP_INTOBJ_INT(1) )
    libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE__HIT, t_2 );
    
    /* return WITH_IMPS_FLAGS_CACHE[hash2 + 1]; */
    t_3 = libGAP_GC_WITH__IMPS__FLAGS__CACHE;
    libGAP_CHECK_BOUND( t_3, "WITH_IMPS_FLAGS_CACHE" )
    libGAP_C_SUM_FIA( t_4, l_hash2, libGAP_INTOBJ_INT(1) )
    libGAP_CHECK_INT_POS( t_4 )
    libGAP_C_ELM_LIST_FPL( t_2, t_3, t_4 )
    libGAP_RES_BRK_CURR_STAT();
    libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
    return t_2;
    
   }
   /* fi */
   
  }
  
  /* else */
  else {
   
   /* break; */
   break;
   
  }
  /* fi */
  
 }
 /* od */
 
 /* if i = 3 then */
 t_1 = (libGAP_Obj)(libGAP_UInt)(((libGAP_Int)l_i) == ((libGAP_Int)libGAP_INTOBJ_INT(3)));
 if ( t_1 ) {
  
  /* WITH_IMPS_FLAGS_COUNT := (WITH_IMPS_FLAGS_COUNT + 1) mod 4; */
  t_3 = libGAP_GC_WITH__IMPS__FLAGS__COUNT;
  libGAP_CHECK_BOUND( t_3, "WITH_IMPS_FLAGS_COUNT" )
  libGAP_C_SUM_FIA( t_2, t_3, libGAP_INTOBJ_INT(1) )
  t_1 = libGAP_MOD( t_2, libGAP_INTOBJ_INT(4) );
  libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__COUNT, t_1 );
  
  /* i := WITH_IMPS_FLAGS_COUNT; */
  t_1 = libGAP_GC_WITH__IMPS__FLAGS__COUNT;
  libGAP_CHECK_BOUND( t_1, "WITH_IMPS_FLAGS_COUNT" )
  l_i = t_1;
  
  /* hash2 := 2 * ((hash + 31 * i) mod 11001) + 1; */
  libGAP_C_PROD_FIA( t_5, libGAP_INTOBJ_INT(31), l_i )
  libGAP_C_SUM_FIA( t_4, l_hash, t_5 )
  t_3 = libGAP_MOD( t_4, libGAP_INTOBJ_INT(11001) );
  libGAP_C_PROD_FIA( t_2, libGAP_INTOBJ_INT(2), t_3 )
  libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(1) )
  l_hash2 = t_1;
  
 }
 /* fi */
 
 /* WITH_IMPS_FLAGS_CACHE_MISS := WITH_IMPS_FLAGS_CACHE_MISS + 1; */
 t_2 = libGAP_GC_WITH__IMPS__FLAGS__CACHE__MISS;
 libGAP_CHECK_BOUND( t_2, "WITH_IMPS_FLAGS_CACHE_MISS" )
 libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(1) )
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE__MISS, t_1 );
 
 /* with := flags; */
 l_with = a_flags;
 
 /* changed := true; */
 t_1 = libGAP_True;
 l_changed = t_1;
 
 /* while changed od */
 while ( 1 ) {
  t_1 = (libGAP_Obj)(libGAP_UInt)(l_changed != libGAP_False);
  if ( ! t_1 ) break;
  
  /* changed := false; */
  t_1 = libGAP_False;
  l_changed = t_1;
  
  /* for imp in IMPLICATIONS do */
  t_4 = libGAP_GC_IMPLICATIONS;
  libGAP_CHECK_BOUND( t_4, "IMPLICATIONS" )
  if ( libGAP_IS_SMALL_LIST(t_4) ) {
   t_3 = (libGAP_Obj)(libGAP_UInt)1;
   t_1 = libGAP_INTOBJ_INT(1);
  }
  else {
   t_3 = (libGAP_Obj)(libGAP_UInt)0;
   t_1 = libGAP_CALL_1ARGS( libGAP_GF_ITERATOR, t_4 );
  }
  while ( 1 ) {
   if ( t_3 ) {
    if ( libGAP_LEN_LIST(t_4) < libGAP_INT_INTOBJ(t_1) )  break;
    t_2 = libGAP_ELMV0_LIST( t_4, libGAP_INT_INTOBJ(t_1) );
    t_1 = (libGAP_Obj)(((libGAP_UInt)t_1)+4);
    if ( t_2 == 0 )  continue;
   }
   else {
    if ( libGAP_CALL_1ARGS( libGAP_GF_IS_DONE_ITER, t_1 ) != libGAP_False )  break;
    t_2 = libGAP_CALL_1ARGS( libGAP_GF_NEXT_ITER, t_1 );
   }
   l_imp = t_2;
   
   /* if IS_SUBSET_FLAGS( with, imp[2] ) and not IS_SUBSET_FLAGS( with, imp[1] ) then */
   t_8 = libGAP_GF_IS__SUBSET__FLAGS;
   libGAP_C_ELM_LIST_FPL( t_9, l_imp, libGAP_INTOBJ_INT(2) )
   t_7 = libGAP_CALL_2ARGS( t_8, l_with, t_9 );
   libGAP_CHECK_FUNC_RESULT( t_7 )
   libGAP_CHECK_BOOL( t_7 )
   t_6 = (libGAP_Obj)(libGAP_UInt)(t_7 != libGAP_False);
   t_5 = t_6;
   if ( t_5 ) {
    t_10 = libGAP_GF_IS__SUBSET__FLAGS;
    libGAP_C_ELM_LIST_FPL( t_11, l_imp, libGAP_INTOBJ_INT(1) )
    t_9 = libGAP_CALL_2ARGS( t_10, l_with, t_11 );
    libGAP_CHECK_FUNC_RESULT( t_9 )
    libGAP_CHECK_BOOL( t_9 )
    t_8 = (libGAP_Obj)(libGAP_UInt)(t_9 != libGAP_False);
    t_7 = (libGAP_Obj)(libGAP_UInt)( ! ((libGAP_Int)t_8) );
    t_5 = t_7;
   }
   if ( t_5 ) {
    
    /* with := AND_FLAGS( with, imp[1] ); */
    t_6 = libGAP_GF_AND__FLAGS;
    libGAP_C_ELM_LIST_FPL( t_7, l_imp, libGAP_INTOBJ_INT(1) )
    t_5 = libGAP_CALL_2ARGS( t_6, l_with, t_7 );
    libGAP_CHECK_FUNC_RESULT( t_5 )
    l_with = t_5;
    
    /* changed := true; */
    t_5 = libGAP_True;
    l_changed = t_5;
    
   }
   /* fi */
   
  }
  /* od */
  
 }
 /* od */
 
 /* WITH_IMPS_FLAGS_CACHE[hash2] := flags; */
 t_1 = libGAP_GC_WITH__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_1, "WITH_IMPS_FLAGS_CACHE" )
 libGAP_CHECK_INT_POS( l_hash2 )
 libGAP_C_ASS_LIST_FPL( t_1, l_hash2, a_flags )
 
 /* WITH_IMPS_FLAGS_CACHE[hash2 + 1] := with; */
 t_1 = libGAP_GC_WITH__IMPS__FLAGS__CACHE;
 libGAP_CHECK_BOUND( t_1, "WITH_IMPS_FLAGS_CACHE" )
 libGAP_C_SUM_FIA( t_2, l_hash2, libGAP_INTOBJ_INT(1) )
 libGAP_CHECK_INT_POS( t_2 )
 libGAP_C_ASS_LIST_FPL( t_1, t_2, l_with )
 
 /* return with; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return l_with;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 6 */
static libGAP_Obj  libGAP_HdlrFunc6 (
 libGAP_Obj  self,
 libGAP_Obj  a_filter )
{
 libGAP_Obj l_rank = 0;
 libGAP_Obj l_flags = 0;
 libGAP_Obj l_i = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Obj t_5 = 0;
 libGAP_Obj t_6 = 0;
 libGAP_Obj t_7 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* rank := 0; */
 l_rank = libGAP_INTOBJ_INT(0);
 
 /* if IS_FUNCTION( filter ) then */
 t_3 = libGAP_GF_IS__FUNCTION;
 t_2 = libGAP_CALL_1ARGS( t_3, a_filter );
 libGAP_CHECK_FUNC_RESULT( t_2 )
 libGAP_CHECK_BOOL( t_2 )
 t_1 = (libGAP_Obj)(libGAP_UInt)(t_2 != libGAP_False);
 if ( t_1 ) {
  
  /* flags := FLAGS_FILTER( filter ); */
  t_2 = libGAP_GF_FLAGS__FILTER;
  t_1 = libGAP_CALL_1ARGS( t_2, a_filter );
  libGAP_CHECK_FUNC_RESULT( t_1 )
  l_flags = t_1;
  
 }
 
 /* else */
 else {
  
  /* flags := filter; */
  l_flags = a_filter;
  
 }
 /* fi */
 
 /* for i in TRUES_FLAGS( WITH_HIDDEN_IMPS_FLAGS( flags ) ) do */
 t_5 = libGAP_GF_TRUES__FLAGS;
 t_7 = libGAP_GF_WITH__HIDDEN__IMPS__FLAGS;
 t_6 = libGAP_CALL_1ARGS( t_7, l_flags );
 libGAP_CHECK_FUNC_RESULT( t_6 )
 t_4 = libGAP_CALL_1ARGS( t_5, t_6 );
 libGAP_CHECK_FUNC_RESULT( t_4 )
 if ( libGAP_IS_SMALL_LIST(t_4) ) {
  t_3 = (libGAP_Obj)(libGAP_UInt)1;
  t_1 = libGAP_INTOBJ_INT(1);
 }
 else {
  t_3 = (libGAP_Obj)(libGAP_UInt)0;
  t_1 = libGAP_CALL_1ARGS( libGAP_GF_ITERATOR, t_4 );
 }
 while ( 1 ) {
  if ( t_3 ) {
   if ( libGAP_LEN_LIST(t_4) < libGAP_INT_INTOBJ(t_1) )  break;
   t_2 = libGAP_ELMV0_LIST( t_4, libGAP_INT_INTOBJ(t_1) );
   t_1 = (libGAP_Obj)(((libGAP_UInt)t_1)+4);
   if ( t_2 == 0 )  continue;
  }
  else {
   if ( libGAP_CALL_1ARGS( libGAP_GF_IS_DONE_ITER, t_1 ) != libGAP_False )  break;
   t_2 = libGAP_CALL_1ARGS( libGAP_GF_NEXT_ITER, t_1 );
  }
  l_i = t_2;
  
  /* if IsBound( RANK_FILTERS[i] ) then */
  t_7 = libGAP_GC_RANK__FILTERS;
  libGAP_CHECK_BOUND( t_7, "RANK_FILTERS" )
  libGAP_CHECK_INT_POS( l_i )
  t_6 = libGAP_C_ISB_LIST( t_7, l_i );
  t_5 = (libGAP_Obj)(libGAP_UInt)(t_6 != libGAP_False);
  if ( t_5 ) {
   
   /* rank := rank + RANK_FILTERS[i]; */
   t_7 = libGAP_GC_RANK__FILTERS;
   libGAP_CHECK_BOUND( t_7, "RANK_FILTERS" )
   libGAP_C_ELM_LIST_FPL( t_6, t_7, l_i )
   libGAP_C_SUM_FIA( t_5, l_rank, t_6 )
   l_rank = t_5;
   
  }
  
  /* else */
  else {
   
   /* rank := rank + 1; */
   libGAP_C_SUM_FIA( t_5, l_rank, libGAP_INTOBJ_INT(1) )
   l_rank = t_5;
   
  }
  /* fi */
  
 }
 /* od */
 
 /* return rank; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return l_rank;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 7 */
static libGAP_Obj  libGAP_HdlrFunc7 (
 libGAP_Obj  self,
 libGAP_Obj  a_filter )
{
 libGAP_Obj l_hash = 0;
 libGAP_Obj l_rank = 0;
 libGAP_Obj l_flags = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* if IS_FUNCTION( filter ) then */
 t_3 = libGAP_GF_IS__FUNCTION;
 t_2 = libGAP_CALL_1ARGS( t_3, a_filter );
 libGAP_CHECK_FUNC_RESULT( t_2 )
 libGAP_CHECK_BOOL( t_2 )
 t_1 = (libGAP_Obj)(libGAP_UInt)(t_2 != libGAP_False);
 if ( t_1 ) {
  
  /* flags := FLAGS_FILTER( filter ); */
  t_2 = libGAP_GF_FLAGS__FILTER;
  t_1 = libGAP_CALL_1ARGS( t_2, a_filter );
  libGAP_CHECK_FUNC_RESULT( t_1 )
  l_flags = t_1;
  
 }
 
 /* else */
 else {
  
  /* flags := filter; */
  l_flags = a_filter;
  
 }
 /* fi */
 
 /* hash := HASH_FLAGS( flags ); */
 t_2 = libGAP_GF_HASH__FLAGS;
 t_1 = libGAP_CALL_1ARGS( t_2, l_flags );
 libGAP_CHECK_FUNC_RESULT( t_1 )
 l_hash = t_1;
 
 /* rank := RANK_FILTER( flags ); */
 t_2 = libGAP_GF_RANK__FILTER;
 t_1 = libGAP_CALL_1ARGS( t_2, l_flags );
 libGAP_CHECK_FUNC_RESULT( t_1 )
 l_rank = t_1;
 
 /* ADD_LIST( RANK_FILTER_LIST_CURRENT, hash ); */
 t_1 = libGAP_GF_ADD__LIST;
 t_2 = libGAP_GC_RANK__FILTER__LIST__CURRENT;
 libGAP_CHECK_BOUND( t_2, "RANK_FILTER_LIST_CURRENT" )
 libGAP_CALL_2ARGS( t_1, t_2, l_hash );
 
 /* ADD_LIST( RANK_FILTER_LIST_CURRENT, rank ); */
 t_1 = libGAP_GF_ADD__LIST;
 t_2 = libGAP_GC_RANK__FILTER__LIST__CURRENT;
 libGAP_CHECK_BOUND( t_2, "RANK_FILTER_LIST_CURRENT" )
 libGAP_CALL_2ARGS( t_1, t_2, l_rank );
 
 /* return rank; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return l_rank;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 8 */
static libGAP_Obj  libGAP_HdlrFunc8 (
 libGAP_Obj  self,
 libGAP_Obj  a_filter )
{
 libGAP_Obj l_hash = 0;
 libGAP_Obj l_flags = 0;
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* if IS_FUNCTION( filter ) then */
 t_3 = libGAP_GF_IS__FUNCTION;
 t_2 = libGAP_CALL_1ARGS( t_3, a_filter );
 libGAP_CHECK_FUNC_RESULT( t_2 )
 libGAP_CHECK_BOOL( t_2 )
 t_1 = (libGAP_Obj)(libGAP_UInt)(t_2 != libGAP_False);
 if ( t_1 ) {
  
  /* flags := FLAGS_FILTER( filter ); */
  t_2 = libGAP_GF_FLAGS__FILTER;
  t_1 = libGAP_CALL_1ARGS( t_2, a_filter );
  libGAP_CHECK_FUNC_RESULT( t_1 )
  l_flags = t_1;
  
 }
 
 /* else */
 else {
  
  /* flags := filter; */
  l_flags = a_filter;
  
 }
 /* fi */
 
 /* hash := HASH_FLAGS( flags ); */
 t_2 = libGAP_GF_HASH__FLAGS;
 t_1 = libGAP_CALL_1ARGS( t_2, l_flags );
 libGAP_CHECK_FUNC_RESULT( t_1 )
 l_hash = t_1;
 
 /* if hash <> RANK_FILTER_LIST[RANK_FILTER_COUNT] then */
 t_3 = libGAP_GC_RANK__FILTER__LIST;
 libGAP_CHECK_BOUND( t_3, "RANK_FILTER_LIST" )
 t_4 = libGAP_GC_RANK__FILTER__COUNT;
 libGAP_CHECK_BOUND( t_4, "RANK_FILTER_COUNT" )
 libGAP_CHECK_INT_POS( t_4 )
 libGAP_C_ELM_LIST_FPL( t_2, t_3, t_4 )
 t_1 = (libGAP_Obj)(libGAP_UInt)( ! libGAP_EQ( l_hash, t_2 ));
 if ( t_1 ) {
  
  /* Error( "corrupted completion file" ); */
  t_1 = libGAP_GF_Error;
  libGAP_C_NEW_STRING( t_2, 25, "corrupted completion file" );
  libGAP_CALL_1ARGS( t_1, t_2 );
  
 }
 /* fi */
 
 /* RANK_FILTER_COUNT := RANK_FILTER_COUNT + 2; */
 t_2 = libGAP_GC_RANK__FILTER__COUNT;
 libGAP_CHECK_BOUND( t_2, "RANK_FILTER_COUNT" )
 libGAP_C_SUM_FIA( t_1, t_2, libGAP_INTOBJ_INT(2) )
 libGAP_AssGVar( libGAP_G_RANK__FILTER__COUNT, t_1 );
 
 /* return RANK_FILTER_LIST[RANK_FILTER_COUNT - 1]; */
 t_2 = libGAP_GC_RANK__FILTER__LIST;
 libGAP_CHECK_BOUND( t_2, "RANK_FILTER_LIST" )
 t_4 = libGAP_GC_RANK__FILTER__COUNT;
 libGAP_CHECK_BOUND( t_4, "RANK_FILTER_COUNT" )
 libGAP_C_DIFF_FIA( t_3, t_4, libGAP_INTOBJ_INT(1) )
 libGAP_CHECK_INT_POS( t_3 )
 libGAP_C_ELM_LIST_FPL( t_1, t_2, t_3 )
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return t_1;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* handler for function 1 */
static libGAP_Obj  libGAP_HdlrFunc1 (
 libGAP_Obj  self )
{
 libGAP_Obj t_1 = 0;
 libGAP_Obj t_2 = 0;
 libGAP_Obj t_3 = 0;
 libGAP_Obj t_4 = 0;
 libGAP_Bag oldFrame;
 libGAP_OLD_BRK_CURR_STAT
 
 /* allocate new stack frame */
 libGAP_SWITCH_TO_NEW_FRAME(self,0,0,oldFrame);
 libGAP_REM_BRK_CURR_STAT();
 libGAP_SET_BRK_CURR_STAT(0);
 
 /* HIDDEN_IMPS := [  ]; */
 t_1 = libGAP_NEW_PLIST( libGAP_T_PLIST, 0 );
 libGAP_SET_LEN_PLIST( t_1, 0 );
 libGAP_AssGVar( libGAP_G_HIDDEN__IMPS, t_1 );
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE := [  ]; */
 t_1 = libGAP_NEW_PLIST( libGAP_T_PLIST, 0 );
 libGAP_SET_LEN_PLIST( t_1, 0 );
 libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE, t_1 );
 
 /* WITH_HIDDEN_IMPS_FLAGS_COUNT := 0; */
 libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__COUNT, libGAP_INTOBJ_INT(0) );
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS := 0; */
 libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS, libGAP_INTOBJ_INT(0) );
 
 /* WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT := 0; */
 libGAP_AssGVar( libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT, libGAP_INTOBJ_INT(0) );
 
 /* Unbind( CLEAR_HIDDEN_IMP_CACHE ); */
 libGAP_AssGVar( libGAP_G_CLEAR__HIDDEN__IMP__CACHE, 0 );
 
 /* BIND_GLOBAL( "CLEAR_HIDDEN_IMP_CACHE", function ( filter )
      local  i, flags;
      flags := FLAGS_FILTER( filter );
      for i  in [ 1, 3 .. LEN_LIST( WITH_HIDDEN_IMPS_FLAGS_CACHE ) - 1 ]  do
          if IsBound( WITH_HIDDEN_IMPS_FLAGS_CACHE[i] )  then
              if IS_SUBSET_FLAGS( WITH_HIDDEN_IMPS_FLAGS_CACHE[i + 1], flags )  then
                  Unbind( WITH_HIDDEN_IMPS_FLAGS_CACHE[i] );
                  Unbind( WITH_HIDDEN_IMPS_FLAGS_CACHE[i + 1] );
              fi;
          fi;
      od;
      return;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 22, "CLEAR_HIDDEN_IMP_CACHE" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[2], libGAP_NargFunc[2], libGAP_NamsFunc[2], libGAP_HdlrFunc2 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(26);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(38);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* BIND_GLOBAL( "WITH_HIDDEN_IMPS_FLAGS", function ( flags )
      local  with, changed, imp, hash;
      hash := 2 * (HASH_FLAGS( flags ) mod 1009) + 1;
      if IsBound( WITH_HIDDEN_IMPS_FLAGS_CACHE[hash] )  then
          if IS_IDENTICAL_OBJ( WITH_HIDDEN_IMPS_FLAGS_CACHE[hash], flags )  then
              WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT := WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT + 1;
              return WITH_HIDDEN_IMPS_FLAGS_CACHE[hash + 1];
          fi;
      fi;
      WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS := WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS + 1;
      with := flags;
      changed := true;
      while changed  do
          changed := false;
          for imp  in HIDDEN_IMPS  do
              if IS_SUBSET_FLAGS( with, imp[2] ) and not IS_SUBSET_FLAGS( with, imp[1] )  then
                  with := AND_FLAGS( with, imp[1] );
                  changed := true;
              fi;
          od;
      od;
      WITH_HIDDEN_IMPS_FLAGS_CACHE[hash] := flags;
      WITH_HIDDEN_IMPS_FLAGS_CACHE[hash + 1] := with;
      return with;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 22, "WITH_HIDDEN_IMPS_FLAGS" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[3], libGAP_NargFunc[3], libGAP_NamsFunc[3], libGAP_HdlrFunc3 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(41);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(71);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* IMPLICATIONS := [  ]; */
 t_1 = libGAP_NEW_PLIST( libGAP_T_PLIST, 0 );
 libGAP_SET_LEN_PLIST( t_1, 0 );
 libGAP_AssGVar( libGAP_G_IMPLICATIONS, t_1 );
 
 /* WITH_IMPS_FLAGS_CACHE := [  ]; */
 t_1 = libGAP_NEW_PLIST( libGAP_T_PLIST, 0 );
 libGAP_SET_LEN_PLIST( t_1, 0 );
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE, t_1 );
 
 /* WITH_IMPS_FLAGS_COUNT := 0; */
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__COUNT, libGAP_INTOBJ_INT(0) );
 
 /* WITH_IMPS_FLAGS_CACHE_HIT := 0; */
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE__HIT, libGAP_INTOBJ_INT(0) );
 
 /* WITH_IMPS_FLAGS_CACHE_MISS := 0; */
 libGAP_AssGVar( libGAP_G_WITH__IMPS__FLAGS__CACHE__MISS, libGAP_INTOBJ_INT(0) );
 
 /* Unbind( CLEAR_IMP_CACHE ); */
 libGAP_AssGVar( libGAP_G_CLEAR__IMP__CACHE, 0 );
 
 /* BIND_GLOBAL( "CLEAR_IMP_CACHE", function (  )
      WITH_IMPS_FLAGS_CACHE := [  ];
      return;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 15, "CLEAR_IMP_CACHE" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[4], libGAP_NargFunc[4], libGAP_NamsFunc[4], libGAP_HdlrFunc4 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(86);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(88);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* BIND_GLOBAL( "WITH_IMPS_FLAGS", function ( flags )
      local  with, changed, imp, hash, hash2, i;
      hash := HASH_FLAGS( flags ) mod 11001;
      for i  in [ 0 .. 3 ]  do
          hash2 := 2 * ((hash + 31 * i) mod 11001) + 1;
          if IsBound( WITH_IMPS_FLAGS_CACHE[hash2] )  then
              if IS_IDENTICAL_OBJ( WITH_IMPS_FLAGS_CACHE[hash2], flags )  then
                  WITH_IMPS_FLAGS_CACHE_HIT := WITH_IMPS_FLAGS_CACHE_HIT + 1;
                  return WITH_IMPS_FLAGS_CACHE[hash2 + 1];
              fi;
          else
              break;
          fi;
      od;
      if i = 3  then
          WITH_IMPS_FLAGS_COUNT := (WITH_IMPS_FLAGS_COUNT + 1) mod 4;
          i := WITH_IMPS_FLAGS_COUNT;
          hash2 := 2 * ((hash + 31 * i) mod 11001) + 1;
      fi;
      WITH_IMPS_FLAGS_CACHE_MISS := WITH_IMPS_FLAGS_CACHE_MISS + 1;
      with := flags;
      changed := true;
      while changed  do
          changed := false;
          for imp  in IMPLICATIONS  do
              if IS_SUBSET_FLAGS( with, imp[2] ) and not IS_SUBSET_FLAGS( with, imp[1] )  then
                  with := AND_FLAGS( with, imp[1] );
                  changed := true;
              fi;
          od;
      od;
      WITH_IMPS_FLAGS_CACHE[hash2] := flags;
      WITH_IMPS_FLAGS_CACHE[hash2 + 1] := with;
      return with;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 15, "WITH_IMPS_FLAGS" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[5], libGAP_NargFunc[5], libGAP_NamsFunc[5], libGAP_HdlrFunc5 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(91);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(130);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* UNBIND_GLOBAL( "RANK_FILTER" ); */
 t_1 = libGAP_GF_UNBIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" );
 libGAP_CALL_1ARGS( t_1, t_2 );
 
 /* BIND_GLOBAL( "RANK_FILTER", function ( filter )
      local  rank, flags, i;
      rank := 0;
      if IS_FUNCTION( filter )  then
          flags := FLAGS_FILTER( filter );
      else
          flags := filter;
      fi;
      for i  in TRUES_FLAGS( WITH_HIDDEN_IMPS_FLAGS( flags ) )  do
          if IsBound( RANK_FILTERS[i] )  then
              rank := rank + RANK_FILTERS[i];
          else
              rank := rank + 1;
          fi;
      od;
      return rank;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 11, "RANK_FILTER" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[6], libGAP_NargFunc[6], libGAP_NamsFunc[6], libGAP_HdlrFunc6 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(144);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(161);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* RankFilter := RANK_FILTER; */
 t_1 = libGAP_GC_RANK__FILTER;
 libGAP_CHECK_BOUND( t_1, "RANK_FILTER" )
 libGAP_AssGVar( libGAP_G_RankFilter, t_1 );
 
 /* UNBIND_GLOBAL( "RANK_FILTER_STORE" ); */
 t_1 = libGAP_GF_UNBIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" );
 libGAP_CALL_1ARGS( t_1, t_2 );
 
 /* BIND_GLOBAL( "RANK_FILTER_STORE", function ( filter )
      local  hash, rank, flags;
      if IS_FUNCTION( filter )  then
          flags := FLAGS_FILTER( filter );
      else
          flags := filter;
      fi;
      hash := HASH_FLAGS( flags );
      rank := RANK_FILTER( flags );
      ADD_LIST( RANK_FILTER_LIST_CURRENT, hash );
      ADD_LIST( RANK_FILTER_LIST_CURRENT, rank );
      return rank;
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 17, "RANK_FILTER_STORE" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[7], libGAP_NargFunc[7], libGAP_NamsFunc[7], libGAP_HdlrFunc7 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(166);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(180);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* UNBIND_GLOBAL( "RANK_FILTER_COMPLETION" ); */
 t_1 = libGAP_GF_UNBIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" );
 libGAP_CALL_1ARGS( t_1, t_2 );
 
 /* BIND_GLOBAL( "RANK_FILTER_COMPLETION", function ( filter )
      local  hash, flags;
      if IS_FUNCTION( filter )  then
          flags := FLAGS_FILTER( filter );
      else
          flags := filter;
      fi;
      hash := HASH_FLAGS( flags );
      if hash <> RANK_FILTER_LIST[RANK_FILTER_COUNT]  then
          Error( "corrupted completion file" );
      fi;
      RANK_FILTER_COUNT := RANK_FILTER_COUNT + 2;
      return RANK_FILTER_LIST[RANK_FILTER_COUNT - 1];
  end ); */
 t_1 = libGAP_GF_BIND__GLOBAL;
 libGAP_C_NEW_STRING( t_2, 22, "RANK_FILTER_COMPLETION" );
 t_3 = libGAP_NewFunction( libGAP_NameFunc[8], libGAP_NargFunc[8], libGAP_NamsFunc[8], libGAP_HdlrFunc8 );
 libGAP_ENVI_FUNC( t_3 ) = libGAP_CurrLVars;
 t_4 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj) );
 libGAP_STARTLINE_BODY(t_4) = libGAP_INTOBJ_INT(183);
 libGAP_ENDLINE_BODY(t_4) = libGAP_INTOBJ_INT(198);
 libGAP_FILENAME_BODY(t_4) = libGAP_FileName;
 libGAP_BODY_FUNC(t_3) = t_4;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 libGAP_CALL_2ARGS( t_1, t_2, t_3 );
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
 
 /* return; */
 libGAP_RES_BRK_CURR_STAT();
 libGAP_SWITCH_TO_OLD_FRAME(oldFrame);
 return 0;
}

/* 'InitKernel' sets up data structures, fopies, copies, handlers */
static libGAP_Int libGAP_InitKernel ( libGAP_StructInitInfo * libGAP_module )
{
 
 /* global variables used in handlers */
 libGAP_InitFopyGVar( "IS_FUNCTION", &libGAP_GF_IS__FUNCTION );
 libGAP_InitFopyGVar( "ADD_LIST", &libGAP_GF_ADD__LIST );
 libGAP_InitFopyGVar( "Error", &libGAP_GF_Error );
 libGAP_InitFopyGVar( "IS_IDENTICAL_OBJ", &libGAP_GF_IS__IDENTICAL__OBJ );
 libGAP_InitFopyGVar( "AND_FLAGS", &libGAP_GF_AND__FLAGS );
 libGAP_InitFopyGVar( "HASH_FLAGS", &libGAP_GF_HASH__FLAGS );
 libGAP_InitFopyGVar( "IS_SUBSET_FLAGS", &libGAP_GF_IS__SUBSET__FLAGS );
 libGAP_InitFopyGVar( "TRUES_FLAGS", &libGAP_GF_TRUES__FLAGS );
 libGAP_InitFopyGVar( "FLAGS_FILTER", &libGAP_GF_FLAGS__FILTER );
 libGAP_InitFopyGVar( "LEN_LIST", &libGAP_GF_LEN__LIST );
 libGAP_InitCopyGVar( "HIDDEN_IMPS", &libGAP_GC_HIDDEN__IMPS );
 libGAP_InitCopyGVar( "WITH_HIDDEN_IMPS_FLAGS_CACHE", &libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE );
 libGAP_InitCopyGVar( "WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS", &libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS );
 libGAP_InitCopyGVar( "WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT", &libGAP_GC_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT );
 libGAP_InitFopyGVar( "BIND_GLOBAL", &libGAP_GF_BIND__GLOBAL );
 libGAP_InitCopyGVar( "IMPLICATIONS", &libGAP_GC_IMPLICATIONS );
 libGAP_InitCopyGVar( "WITH_IMPS_FLAGS_CACHE", &libGAP_GC_WITH__IMPS__FLAGS__CACHE );
 libGAP_InitCopyGVar( "WITH_IMPS_FLAGS_COUNT", &libGAP_GC_WITH__IMPS__FLAGS__COUNT );
 libGAP_InitCopyGVar( "WITH_IMPS_FLAGS_CACHE_HIT", &libGAP_GC_WITH__IMPS__FLAGS__CACHE__HIT );
 libGAP_InitCopyGVar( "WITH_IMPS_FLAGS_CACHE_MISS", &libGAP_GC_WITH__IMPS__FLAGS__CACHE__MISS );
 libGAP_InitFopyGVar( "UNBIND_GLOBAL", &libGAP_GF_UNBIND__GLOBAL );
 libGAP_InitFopyGVar( "WITH_HIDDEN_IMPS_FLAGS", &libGAP_GF_WITH__HIDDEN__IMPS__FLAGS );
 libGAP_InitCopyGVar( "RANK_FILTERS", &libGAP_GC_RANK__FILTERS );
 libGAP_InitCopyGVar( "RANK_FILTER", &libGAP_GC_RANK__FILTER );
 libGAP_InitFopyGVar( "RANK_FILTER", &libGAP_GF_RANK__FILTER );
 libGAP_InitCopyGVar( "RANK_FILTER_LIST_CURRENT", &libGAP_GC_RANK__FILTER__LIST__CURRENT );
 libGAP_InitCopyGVar( "RANK_FILTER_LIST", &libGAP_GC_RANK__FILTER__LIST );
 libGAP_InitCopyGVar( "RANK_FILTER_COUNT", &libGAP_GC_RANK__FILTER__COUNT );
 
 /* information for the functions */
 libGAP_InitGlobalBag( &libGAP_DefaultName, "GAPROOT/lib/filter1.g:DefaultName(-34850804)" );
 libGAP_InitGlobalBag( &libGAP_FileName, "GAPROOT/lib/filter1.g:FileName(-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc1, "GAPROOT/lib/filter1.g:HdlrFunc1(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[1]), "GAPROOT/lib/filter1.g:NameFunc[1](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc2, "GAPROOT/lib/filter1.g:HdlrFunc2(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[2]), "GAPROOT/lib/filter1.g:NameFunc[2](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc3, "GAPROOT/lib/filter1.g:HdlrFunc3(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[3]), "GAPROOT/lib/filter1.g:NameFunc[3](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc4, "GAPROOT/lib/filter1.g:HdlrFunc4(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[4]), "GAPROOT/lib/filter1.g:NameFunc[4](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc5, "GAPROOT/lib/filter1.g:HdlrFunc5(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[5]), "GAPROOT/lib/filter1.g:NameFunc[5](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc6, "GAPROOT/lib/filter1.g:HdlrFunc6(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[6]), "GAPROOT/lib/filter1.g:NameFunc[6](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc7, "GAPROOT/lib/filter1.g:HdlrFunc7(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[7]), "GAPROOT/lib/filter1.g:NameFunc[7](-34850804)" );
 libGAP_InitHandlerFunc( libGAP_HdlrFunc8, "GAPROOT/lib/filter1.g:HdlrFunc8(-34850804)" );
 libGAP_InitGlobalBag( &(libGAP_NameFunc[8]), "GAPROOT/lib/filter1.g:NameFunc[8](-34850804)" );
 
 /* return success */
 return 0;
 
}

/* 'InitLibrary' sets up gvars, rnams, functions */
static libGAP_Int libGAP_InitLibrary ( libGAP_StructInitInfo * libGAP_module )
{
 libGAP_Obj func1;
 libGAP_Obj body1;
 
 /* Complete Copy/Fopy registration */
 libGAP_UpdateCopyFopyInfo();
 
 /* global variables used in handlers */
 libGAP_G_IS__FUNCTION = libGAP_GVarName( "IS_FUNCTION" );
 libGAP_G_ADD__LIST = libGAP_GVarName( "ADD_LIST" );
 libGAP_G_Error = libGAP_GVarName( "Error" );
 libGAP_G_IS__IDENTICAL__OBJ = libGAP_GVarName( "IS_IDENTICAL_OBJ" );
 libGAP_G_AND__FLAGS = libGAP_GVarName( "AND_FLAGS" );
 libGAP_G_HASH__FLAGS = libGAP_GVarName( "HASH_FLAGS" );
 libGAP_G_IS__SUBSET__FLAGS = libGAP_GVarName( "IS_SUBSET_FLAGS" );
 libGAP_G_TRUES__FLAGS = libGAP_GVarName( "TRUES_FLAGS" );
 libGAP_G_FLAGS__FILTER = libGAP_GVarName( "FLAGS_FILTER" );
 libGAP_G_LEN__LIST = libGAP_GVarName( "LEN_LIST" );
 libGAP_G_HIDDEN__IMPS = libGAP_GVarName( "HIDDEN_IMPS" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__COUNT = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_COUNT" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT" );
 libGAP_G_CLEAR__HIDDEN__IMP__CACHE = libGAP_GVarName( "CLEAR_HIDDEN_IMP_CACHE" );
 libGAP_G_BIND__GLOBAL = libGAP_GVarName( "BIND_GLOBAL" );
 libGAP_G_IMPLICATIONS = libGAP_GVarName( "IMPLICATIONS" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE" );
 libGAP_G_WITH__IMPS__FLAGS__COUNT = libGAP_GVarName( "WITH_IMPS_FLAGS_COUNT" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE__HIT = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE_HIT" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE__MISS = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE_MISS" );
 libGAP_G_CLEAR__IMP__CACHE = libGAP_GVarName( "CLEAR_IMP_CACHE" );
 libGAP_G_UNBIND__GLOBAL = libGAP_GVarName( "UNBIND_GLOBAL" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS" );
 libGAP_G_RANK__FILTERS = libGAP_GVarName( "RANK_FILTERS" );
 libGAP_G_RankFilter = libGAP_GVarName( "RankFilter" );
 libGAP_G_RANK__FILTER = libGAP_GVarName( "RANK_FILTER" );
 libGAP_G_RANK__FILTER__LIST__CURRENT = libGAP_GVarName( "RANK_FILTER_LIST_CURRENT" );
 libGAP_G_RANK__FILTER__LIST = libGAP_GVarName( "RANK_FILTER_LIST" );
 libGAP_G_RANK__FILTER__COUNT = libGAP_GVarName( "RANK_FILTER_COUNT" );
 
 /* record names used in handlers */
 
 /* information for the functions */
 libGAP_C_NEW_STRING( libGAP_DefaultName, 14, "local function" );
 libGAP_C_NEW_STRING( libGAP_FileName, 21, "GAPROOT/lib/filter1.g" );
 libGAP_NameFunc[1] = libGAP_DefaultName;
 libGAP_NamsFunc[1] = 0;
 libGAP_NargFunc[1] = 0;
 libGAP_NameFunc[2] = libGAP_DefaultName;
 libGAP_NamsFunc[2] = 0;
 libGAP_NargFunc[2] = 1;
 libGAP_NameFunc[3] = libGAP_DefaultName;
 libGAP_NamsFunc[3] = 0;
 libGAP_NargFunc[3] = 1;
 libGAP_NameFunc[4] = libGAP_DefaultName;
 libGAP_NamsFunc[4] = 0;
 libGAP_NargFunc[4] = 0;
 libGAP_NameFunc[5] = libGAP_DefaultName;
 libGAP_NamsFunc[5] = 0;
 libGAP_NargFunc[5] = 1;
 libGAP_NameFunc[6] = libGAP_DefaultName;
 libGAP_NamsFunc[6] = 0;
 libGAP_NargFunc[6] = 1;
 libGAP_NameFunc[7] = libGAP_DefaultName;
 libGAP_NamsFunc[7] = 0;
 libGAP_NargFunc[7] = 1;
 libGAP_NameFunc[8] = libGAP_DefaultName;
 libGAP_NamsFunc[8] = 0;
 libGAP_NargFunc[8] = 1;
 
 /* create all the functions defined in this module */
 func1 = libGAP_NewFunction(libGAP_NameFunc[1],libGAP_NargFunc[1],libGAP_NamsFunc[1],libGAP_HdlrFunc1);
 libGAP_ENVI_FUNC( func1 ) = libGAP_CurrLVars;
 libGAP_CHANGED_BAG( libGAP_CurrLVars );
 body1 = libGAP_NewBag( libGAP_T_BODY, libGAP_NUMBER_HEADER_ITEMS_BODY*sizeof(libGAP_Obj));
 libGAP_BODY_FUNC( func1 ) = body1;
 libGAP_CHANGED_BAG( func1 );
 libGAP_CALL_0ARGS( func1 );
 
 /* return success */
 return 0;
 
}

/* 'PostRestore' restore gvars, rnams, functions */
static libGAP_Int libGAP_PostRestore ( libGAP_StructInitInfo * libGAP_module )
{
 
 /* global variables used in handlers */
 libGAP_G_IS__FUNCTION = libGAP_GVarName( "IS_FUNCTION" );
 libGAP_G_ADD__LIST = libGAP_GVarName( "ADD_LIST" );
 libGAP_G_Error = libGAP_GVarName( "Error" );
 libGAP_G_IS__IDENTICAL__OBJ = libGAP_GVarName( "IS_IDENTICAL_OBJ" );
 libGAP_G_AND__FLAGS = libGAP_GVarName( "AND_FLAGS" );
 libGAP_G_HASH__FLAGS = libGAP_GVarName( "HASH_FLAGS" );
 libGAP_G_IS__SUBSET__FLAGS = libGAP_GVarName( "IS_SUBSET_FLAGS" );
 libGAP_G_TRUES__FLAGS = libGAP_GVarName( "TRUES_FLAGS" );
 libGAP_G_FLAGS__FILTER = libGAP_GVarName( "FLAGS_FILTER" );
 libGAP_G_LEN__LIST = libGAP_GVarName( "LEN_LIST" );
 libGAP_G_HIDDEN__IMPS = libGAP_GVarName( "HIDDEN_IMPS" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__COUNT = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_COUNT" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__MISS = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE_MISS" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS__CACHE__HIT = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS_CACHE_HIT" );
 libGAP_G_CLEAR__HIDDEN__IMP__CACHE = libGAP_GVarName( "CLEAR_HIDDEN_IMP_CACHE" );
 libGAP_G_BIND__GLOBAL = libGAP_GVarName( "BIND_GLOBAL" );
 libGAP_G_IMPLICATIONS = libGAP_GVarName( "IMPLICATIONS" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE" );
 libGAP_G_WITH__IMPS__FLAGS__COUNT = libGAP_GVarName( "WITH_IMPS_FLAGS_COUNT" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE__HIT = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE_HIT" );
 libGAP_G_WITH__IMPS__FLAGS__CACHE__MISS = libGAP_GVarName( "WITH_IMPS_FLAGS_CACHE_MISS" );
 libGAP_G_CLEAR__IMP__CACHE = libGAP_GVarName( "CLEAR_IMP_CACHE" );
 libGAP_G_UNBIND__GLOBAL = libGAP_GVarName( "UNBIND_GLOBAL" );
 libGAP_G_WITH__HIDDEN__IMPS__FLAGS = libGAP_GVarName( "WITH_HIDDEN_IMPS_FLAGS" );
 libGAP_G_RANK__FILTERS = libGAP_GVarName( "RANK_FILTERS" );
 libGAP_G_RankFilter = libGAP_GVarName( "RankFilter" );
 libGAP_G_RANK__FILTER = libGAP_GVarName( "RANK_FILTER" );
 libGAP_G_RANK__FILTER__LIST__CURRENT = libGAP_GVarName( "RANK_FILTER_LIST_CURRENT" );
 libGAP_G_RANK__FILTER__LIST = libGAP_GVarName( "RANK_FILTER_LIST" );
 libGAP_G_RANK__FILTER__COUNT = libGAP_GVarName( "RANK_FILTER_COUNT" );
 
 /* record names used in handlers */
 
 /* information for the functions */
 libGAP_NameFunc[1] = libGAP_DefaultName;
 libGAP_NamsFunc[1] = 0;
 libGAP_NargFunc[1] = 0;
 libGAP_NameFunc[2] = libGAP_DefaultName;
 libGAP_NamsFunc[2] = 0;
 libGAP_NargFunc[2] = 1;
 libGAP_NameFunc[3] = libGAP_DefaultName;
 libGAP_NamsFunc[3] = 0;
 libGAP_NargFunc[3] = 1;
 libGAP_NameFunc[4] = libGAP_DefaultName;
 libGAP_NamsFunc[4] = 0;
 libGAP_NargFunc[4] = 0;
 libGAP_NameFunc[5] = libGAP_DefaultName;
 libGAP_NamsFunc[5] = 0;
 libGAP_NargFunc[5] = 1;
 libGAP_NameFunc[6] = libGAP_DefaultName;
 libGAP_NamsFunc[6] = 0;
 libGAP_NargFunc[6] = 1;
 libGAP_NameFunc[7] = libGAP_DefaultName;
 libGAP_NamsFunc[7] = 0;
 libGAP_NargFunc[7] = 1;
 libGAP_NameFunc[8] = libGAP_DefaultName;
 libGAP_NamsFunc[8] = 0;
 libGAP_NargFunc[8] = 1;
 
 /* return success */
 return 0;
 
}


/* <name> returns the description of this module */
static libGAP_StructInitInfo libGAP_module = {
 /* type        = */ 2,
 /* name        = */ "GAPROOT/lib/filter1.g",
 /* revision_c  = */ 0,
 /* revision_h  = */ 0,
 /* version     = */ 0,
 /* crc         = */ -34850804,
 /* initKernel  = */ libGAP_InitKernel,
 /* initLibrary = */ libGAP_InitLibrary,
 /* checkInit   = */ 0,
 /* preSave     = */ 0,
 /* postSave    = */ 0,
 /* postRestore = */ libGAP_PostRestore
};

libGAP_StructInitInfo * libGAP_Init__filter1 ( void )
{
 return &libGAP_module;
}

/* compiled code ends here */
#endif
